In the nutrition case study, a factor is considered "kept" if at least one loading exceeds a small threshold in absolute value.
Arguments
- post
Output of
postprocess_pfa().- threshold
Threshold for considering a column nontrivial (default 1e-3).
In the nutrition case study, a factor is considered "kept" if at least one loading exceeds a small threshold in absolute value.
Output of postprocess_pfa().
Threshold for considering a column nontrivial (default 1e-3).